@@ -74,11 +74,11 @@ cooccur.dataprepreprocess.preprocess <- function(data=list(), threshold=0.9, par
       #memory="memory"
     #}
   #}
-  #2016-08-30 end 
- 
-  
-  
-  
+  #2016-08-30 end
+
+
+
+
 
 
 
@@ -88,8 +88,8 @@ cooccur.dataprepreprocess.preprocess <- function(data=list(), threshold=0.9, par
     data$original <- data$original[,-fable]
   }
   #sfStop()
-  
-  
+
+
   inmemoryflag = inmemoryflag(nrow(data$matrix), ncol(data$matrix))
 
   if(is.na(memory)==TRUE){
@@ -98,8 +98,8 @@ cooccur.dataprepreprocess.preprocess <- function(data=list(), threshold=0.9, par
     }else{
       memory="sparse"
     }
-  }  
-    
+  }
+
   msg = paste('using memory,', memory, sep="")
   cooccur.printTimeCost(msg, t, debug)
 
@@ -111,26 +111,34 @@ cooccur.dataprepreprocess.preprocess <- function(data=list(), threshold=0.9, par
   #step3. create big memory matrix of column-column relation
   t = Sys.time()
   filename = data$dt_idxtable_filename
-  data$dt_idxtable <- cooccur.geneColumnCombination.bigmemory(ncol(data$matrix),filename,memory)	#recalculate ncol(matrix)
-  #data$dt_idxtable <- cooccur.geneColumnCombination.dt(ncol(data$matrix))
+
+  #2016-09-19 begin
+  #data$dt_idxtable <- cooccur.geneColumnCombination.bigmemory(ncol(data$matrix),filename,memory)	#recalculate ncol(matrix)
+
+  data$dt_idxtable <- cooccur.geneColumnCombination.normal(ncol(data$matrix),filename,memory)
+  #2016-09-19 end
+   #data$dt_idxtable <- cooccur.geneColumnCombination.dt(ncol(data$matrix))
   cooccur.printTimeCost('create ColumnCombination table dt_idxtable time cost',t,debug)
 
   #gc memory
   gc()
 
-
+  #memory="memory"
 
   #step4. calculation bigramfrequency
   t = Sys.time()
   if(memory=="memory"){
-    cat("calculating networks ......")
+    cat("calculating bigram frequency ......")
     message("")
     data$bigramFreqList <- cooccur.dataprepreprocess.bigramfrequence(data)
+    #print(data$bigramFreqList[,])
     data$memory <- "memory"
   }else if(memory=="sparse"){
     data$memory <- "sparse"
   }
 
+
+
   cooccur.printTimeCost('create bi-grams frequence table time cost',t,debug)
   #print(paste('create bi-grams frequence table time cost:', round((Sys.time()-t),2),' secs')	)
 
@@ -145,11 +153,11 @@ cooccur.dataprepreprocess.preprocess <- function(data=list(), threshold=0.9, par
 #' @importFrom   foreach %do%
 #' @importFrom utils memory.size setTxtProgressBar txtProgressBar write.table
 cooccur.dataprepreprocess.bigramfrequence <- function(sequences,colsperIter=20){
-  
+
   #print(dim(sequences$matrix))
   #print(dim(sequences$original))
-  
-  
+
+
   if(!requireNamespace("bigmemory", quietly = TRUE)){
     stop("Package 'bigmemory' is required.")
   }
@@ -165,7 +173,7 @@ cooccur.dataprepreprocess.bigramfrequence <- function(sequences,colsperIter=20){
   #cooccur.printTimeCost('cooccur.dataprepreprocess.bigramfrequence',t1,debug)
 
   #print(len)
-  
+
   #2016-09-05
   colsperIter = 50
   #if(len<2001){
@@ -202,14 +210,14 @@ cooccur.dataprepreprocess.bigramfrequence <- function(sequences,colsperIter=20){
     #print(dim(sequences$matrix[,i]))
     xx = matrix(nrow=nrow, ncol=length(i))
     storage.mode(xx) <- "integer"
-    
-    
- 
+
+
+
     #2016-09-04
     #xx <- paste(sequences$original[,i], sequences$original[,j],sep = "")
     #xx =  big.matrix(nrow=nrow, ncol=length(i), init=NA, dimnames=list(NULL,1:length(i)))
     xx =   (round( sequences$matrix[,i] / sequences$matrix[,j],5) + sequences$matrix[,i]) * 100000
-	  #xx =    sequences$matrix[,i] * sequences$matrix[,j] + sequences$matrix[,i] 
+	  #xx =    sequences$matrix[,i] * sequences$matrix[,j] + sequences$matrix[,i]
     xx = apply(xx,2, function(x){sequences$constantList$biseqlevel[match(x, sequences$constantList$biseqidlevel)]})
     #sequences$constantList$biseqlevel[match(aa, sequences$constantList$biseqidlevel)]
 
